@@ -15,21 +15,26 @@
 #' @param const_list A list in which each element's name is the name of the
 #' constant to override and the element's value correspond to the new value.
 #'
+#' @param graph A boolean parameter that indicates whether \code{read_xmile}
+#'  returns a graph for the model.
+#'
 #' @return This function returns a list with three elements. The first element,
 #' \emph{description}, is a list that contains the simulation parameters, and
 #' the names and equations (including graphical functions) for each stock or
 #' level, variable and constant. The second element, \emph{deSolve_components},
 #' is a list that contains initial values, constants and the function for
-#' simulating via deSolve. The third element, \emph{igraph} contains the
-#' data.frames for creating a graph with igraph.
+#' simulating via deSolve. The third element (optional), \emph{igraph} contains
+#'  the data.frames for creating a graph with igraph.
 #' @export
 #'
 #' @examples
 #' path <- system.file("models", "SIR.stmx", package = "readsdr")
 #' read_xmile(path)
-read_xmile <- function(filepath, stock_list = NULL, const_list = NULL) {
+read_xmile <- function(filepath, stock_list = NULL, const_list = NULL,
+                       graph = FALSE) {
 
-  model_structure    <- extract_structure_from_XMILE(filepath)
+  model_structure    <- extract_structure_from_XMILE(filepath,
+                                                     const_list = const_list)
 
   if(!is.null(stock_list)) {
     stocks_override <- names(stock_list)
@@ -43,26 +48,28 @@ read_xmile <- function(filepath, stock_list = NULL, const_list = NULL) {
     }
   }
 
-  if(!is.null(const_list)) {
-    model_structure <- override_consts(model_structure, const_list)
-  }
-
   deSolve_components <- get_deSolve_elems(model_structure)
 
-  igraph_inputs      <- tryCatch(
-    error = function(cnd) {
-      warning("This model cannot be converted into a graph (network)",
-              call. = FALSE)
-      NULL
-    },
-    get_igraph_inputs(model_structure)
-  )
-
-  list(
+  output <- list(
     description        = model_structure,
-    deSolve_components = deSolve_components,
-    graph_dfs          = igraph_inputs
-  )
+    deSolve_components = deSolve_components)
+
+  if(graph == TRUE) {
+
+    igraph_inputs      <- tryCatch(
+      error = function(cnd) {
+        warning("This model cannot be converted into a graph (network)",
+                call. = FALSE)
+        NULL
+      },
+      get_igraph_inputs(model_structure)
+    )
+
+    output$graph_dfs <- igraph_inputs
+  }
+
+  output
+
 }
 
 #' Parse XMILE to deSolve components
@@ -92,23 +99,3 @@ xmile_to_deSolve <- function(filepath) {
   model_structure    <- extract_structure_from_XMILE(filepath)
   deSolve_components <- get_deSolve_elems(model_structure)
 }
-
-override_consts <- function(mdl_structure, const_list) {
-  consts_override <- names(const_list)
-  const_names     <- sapply(mdl_structure$constants,
-                            function(const_obj) const_obj$name)
-
-  for(i in seq_len(length(const_list))) {
-    cst     <- consts_override[[i]]
-    pos_cst <- which(cst == const_names)
-
-    if(length(pos_cst) == 0) {
-      msg <- paste0("Can't find constant: ", cst)
-      stop(msg, call. = FALSE)
-    }
-
-    mdl_structure$constants[[pos_cst]]$value <- const_list[[cst]]
-  }
-
-  mdl_structure
-}
