@@ -31,8 +31,8 @@ test_that("the output from read_xmile() is a list", {
 })
 
 test_that("the output from read_xmile() produces the required elements", {
-  expect_named(read_xmile(test_model), c("description", "deSolve_components",
-                                         "graph_dfs"))
+  expect_named(read_xmile(test_model, graph = TRUE),
+               c("description", "deSolve_components", "graph_dfs"))
 })
 
 sd_simulate <- function(mdl, method = "euler") {
@@ -107,47 +107,49 @@ test_that("read_xmile() allows the user to override init values of stocks", {
 })
 
 test_that("read_xmile() allows the user to override values of constants", {
+
   const_list <- list(growth_rate = 0.02)
   mdl        <- read_xmile(test_model, const_list = const_list)
   expect_equal(mdl$description$constants[[1]]$value, 0.02)
   expect_equal(mdl$deSolve_components$consts[[1]], 0.02)
 })
 
+test_that("read_xmile() supports n-dimensional arrays from Vensim", {
+
+  expect_named(read_xmile("./2d_pop.xmile"),
+               c("description", "deSolve_components"))
+
+})
+
+test_that("read_xmile() overrides metaparameter for delay N", {
+
+  expected <- 12
+
+  filepath      <- system.file("models/", "SEjIkR.stmx", package = "readsdr")
+  mdl           <- read_xmile(filepath, const_list = list(j = 5))
+
+  actual   <- length(mdl$description$levels)
+
+  expect_equal(actual, expected)
+
+  filepath <- "./SEjIkR.xmile"
+  mdl      <- read_xmile(filepath, const_list = list(j = 5))
+  actual   <- length(mdl$description$levels)
+
+  expect_equal(actual, expected)
+})
+
+test_that("read_xmile() handles Simlin files", {
+
+  filepath <- "./test_models/SEIR_simlin.stmx"
+
+  mdl <- read_xmile(filepath)
+
+  expect_is(mdl, "list")
+})
+
 #xmile_to_deSolve()-------------------------------------------------------------
 
 test_that("xmile_to_deSolve() returns a list", {
   expect_is(xmile_to_deSolve(test_model), "list")
 })
-
-#override_consts()--------------------------------------------------------------
-
-test_that("override_consts() works for a single change in multiple options", {
-  mdl_structure <- list(constants =
-                          list(list(name  = "growth_rate2",
-                                    value = 0.1),
-                               list(name  = "growth_rate1",
-                                    value = 0.1),
-                               list(name  = "growth_rate3",
-                                    value = 0.1)))
-
-  const_list <- list(growth_rate1 = 0.2)
-
-
-  actual_obj <- override_consts(mdl_structure, const_list)
-
-  expected_obj <- mdl_structure
-  expected_obj$constants[[2]]$value <- 0.2
-
-  expect_equal(actual_obj, expected_obj)
-})
-
-test_that("override_consts throws an error when the constant doesn't exist", {
-  mdl_structure <- list(constants =
-                          list(list(name  = "growth_rate1",
-                               value = 0.1)))
-
-  const_list <- list(growth_rate2 = 0.2)
-
-  expect_error(override_consts(mdl_structure, const_list),
-               "Can't find constant: growth_rate2")
-})
